@@ -28,7 +28,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.34';
+our $VERSION = '2.35';
 
 =head1 SYNOPSIS
 
@@ -341,6 +341,19 @@ has 'use_processes' => (
     required => 0,
 );
 
+=head2 use_gnuparallel 
+
+Bool value to indicate whether or not to use processes. Default is uses processes
+
+=cut
+
+has 'use_gnuparallel' => (
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+    required => 0,
+);
+
 =head1 Internal Variables
 
 You should not need to mess with any of these.
@@ -831,9 +844,9 @@ sub process_batch{
 
     if($self->use_gnuparallel){
         $command = "cd ".getcwd()."\n";
-        $command .= "cat ".$self->cmdfile." | paralellparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
+        $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
     }
-    if($self->use_threads){
+    elsif($self->use_threads){
         $command = "cd ".getcwd()."\n"; #Go back to the working directory just to be safe
         $command .= "paralellrunner.pl --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
     }
